#
# db2_secured::controls::disable_database_discoverability
#
# @summary The `DISCOVER_DB` parameter specifies whether the database can be discovered in the network.
# It is recommended that databases not be discoverable.
# 
# Rationale:
# 
# Discovery capabilities may be used by a malicious entity to derive the names of and target Db2 databases.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::disable_database_discoverability: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::disable_database_discoverability::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `disable_database_discoverability` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 4.1.15
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::disable_database_discoverability {
  db2_secured_setup { "disable_database_discoverability on ${title}":
    ensure => 'present',
  }

  resource_value { "Db2_database[${title}]discover_db":
    allow_create   => true,
    allow_redefine => true,
    value          => 'DISABLE',
  }
}
